=======
History
=======

2021.2.10 (10 February 2021)
----------------------------

* Updated the README file to give a better description.
* Updated the short description in setup.py to work with the new installer.
* Added keywords for better searchability.

2020.2.4 (4 February 2021)
--------------------------

* Internal Changes

  - Corrected an issue in CI.

2021.2.3 (3 February 2021)
--------------------------

* Internal Changes

  - Upgraded to be compatible with the improved version of the
    MolSystem classes for describing the molecular system.

2020.12.4 (4 December 2020)
---------------------------

* Internal Changes

  - Moved the continuous integration (CI) to GitHub Actions from
    TravisCI.
  - Moved documentation from ReadTheDocs to GitHub Pages and
    integrated with the rest of the SEAMM documentation.

2020.11.2 (2 November 2020)
---------------------------

* Moved to the new command-line argument handling.

2020.9.24.1 (24 September 2020)
-------------------------------

* Fixed small bug with the title of the system when generated from SMILES.

2020.9.24 (24 September 2020)
-----------------------------

* Updated to work with the new MolSystem classes describing the
  molecular system.

0.9 (15 April 2020)
-------------------

* Internal changes for compatibility.

0.7.0 (17 December 2019)
------------------------

* Internal changes cleaning the code.
  
0.1.0 (20 January 2018)
-----------------------

* First release on PyPI.
